@@ -1,6 +1,7 @@
 ''' Configuration API client implementation. '''
 
 # pylint: disable=W0613,W0622,C0103,R0913,R0903
+from __future__ import annotations
 
 from abc import ABCMeta
 
@@ -16,7 +17,7 @@ class ConfigurationApi:
     def get_client(token: str,
                    version: str = '3.3',
                    base_url: str = 'api.livechatinc.com',
-                   http2: bool = False):
+                   http2: bool = False) -> ConfigurationApiInterface:
         ''' Returns client for specific Configuration API version.
 
             Args:
@@ -44,7 +45,8 @@ class ConfigurationApi:
 
 class ConfigurationApiInterface(metaclass=ABCMeta):
     ''' Interface class. '''
-    def __init__(self, token: str, version: str, base_url: str, http2: bool):
+    def __init__(self, token: str, version: str, base_url: str,
+                 http2: bool) -> ConfigurationApiInterface:
         self.api_url = f'https://{base_url}/v{version}/configuration/action'
         self.session = httpx.Client(http2=http2,
                                     headers={'Authorization': token})
